@@ -9,8 +9,13 @@
 #include <powerdevilaction.h>
 #include <powerdevilbrightnesslogic.h>
 
+#include <controllers/screenbrightnesscontroller.h> // ScreenBrightnessController::IndicatorHint enum
+
 namespace PowerDevil::BundledActions
 {
+
+// Legacy D-Bus API, operating on a single value instead of per-display.
+// TODO KF7 (or earlier): remove this class and API, we have org.kde.ScreenBrightness instead
 class BrightnessControl : public PowerDevil::Action
 {
     Q_OBJECT
@@ -34,16 +39,17 @@ public:
     int brightnessSteps() const;
 
 public Q_SLOTS:
-    // DBus export
     void increaseBrightness();
     void increaseBrightnessSmall();
     void decreaseBrightness();
     void decreaseBrightnessSmall();
+
+    // DBus export
     void setBrightness(int percent);
     void setBrightnessSilent(int percent);
 
 private Q_SLOTS:
-    void onBrightnessChangedFromController(const BrightnessLogic::BrightnessInfo &brightnessInfo);
+    void onBrightnessChangedFromController(const BrightnessLogic::BrightnessInfo &brightnessInfo, ScreenBrightnessController::IndicatorHint hint);
 
 Q_SIGNALS:
     void brightnessChanged(int value);
@@ -51,9 +57,6 @@ Q_SIGNALS:
     void brightnessMinChanged(int valueMin);
 
 private:
-    int brightnessPercent(float value) const;
-
-    int m_defaultValue = -1;
     BrightnessLogic::BrightnessInfo m_lastBrightnessInfo;
 };
 
