@@ -8,7 +8,6 @@
 #pragma once
 
 #include <powerdevilaction.h>
-#include <powerdevilbrightnesslogic.h>
 
 namespace PowerDevil::BundledActions
 {
@@ -20,17 +19,20 @@ class ScreenBrightnessControl : public PowerDevil::Action, protected QDBusContex
 public:
     explicit ScreenBrightnessControl(QObject *parent);
 
-protected:
-    void onProfileLoad(const QString &previousProfile, const QString &newProfile) override;
-    void triggerImpl(const QVariantMap &args) override;
-    bool isSupported() override;
-
 public:
     bool loadAction(const PowerDevil::ProfileSettings &profileSettings) override;
 
-private:
-    void actOnBrightnessKey(BrightnessLogic::StepAdjustmentAction action);
+protected:
+    void onProfileLoad(const QString &previousProfile, const QString &newProfile) override;
+    void onProfileUnload() override;
+    void triggerImpl(const QVariantMap &args) override;
+    bool isSupported() override;
 
-    double m_configuredBrightnessRatio = 0.0;
+private Q_SLOTS:
+    void displayAdded(const QString &displayId);
+
+private:
+    std::optional<double> m_configuredBrightnessRatio;
+    bool m_supportsBatteryProfiles = false;
 };
 }
