@@ -17,7 +17,6 @@
 
 namespace PowerDevil
 {
-class BackendInterface;
 class Core;
 class ProfileSettings;
 
@@ -148,14 +147,10 @@ protected:
      */
     virtual void triggerImpl(const QVariantMap &args) = 0;
 
-    /**
-     * @returns The BackendInterface
-     */
-    PowerDevil::BackendInterface *backend() const;
     /**
      * @returns The PowerDevil Core
      */
-    PowerDevil::Core *core();
+    PowerDevil::Core *core() const;
 
 protected Q_SLOTS:
     /**
